==> ejc-market-api-3.0.1-20211011.065644-4-sources.jar: com/ejianc/business/market/api/IProjectApi.java <==
package com.ejianc.business.market.api;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.business.market.hystrix.ProjectHystrix;
import com.ejianc.business.market.vo.ProjectRegisterVO;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.core.response.QueryParam;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;

import java.util.List;
import java.util.Map;

/**
 * 项目rpc服务
 *
 * @author cJ
 *
 */
@FeignClient(name= "ejc-market-web", url="${common.env.feign-client-url}", path="ejc-market-web", fallback = ProjectHystrix.class)
public interface IProjectApi {

	/**
	 * 根据sourceId查询项目详情
	 *
	 * @param sourceId
	 * @return
	 */
	@GetMapping(value = "/api/project/queryProjectBySourceId")
	public CommonResponse<ProjectRegisterVO> queryProjectBySourceId(@RequestParam(value = "sourceId") String sourceId);

	/**
	 * @Author mrsir_wxp
	 * @Date 2020/8/21 根据项目部id查询项目信息
	 * @Description queryProjectByProjectDepartmentId
	 * @Param [sourceId]
	 * @Return com.ejianc.framework.core.response.CommonResponse<com.ejianc.business.market.vo.ProjectRegisterVO>
	 */
	@GetMapping(value = "/api/project/queryProjectByProjectDepartmentId")
	CommonResponse<ProjectRegisterVO> queryProjectByProjectDepartmentId(@RequestParam(value = "projectDepartmentId") String projectDepartmentId);

	/**
	 * 根据ids查询项目详情
	 *
	 * @param ids
	 * @return
	 */
	@GetMapping(value = "/api/project/queryProjectByIds")
	public CommonResponse<List<ProjectRegisterVO>> queryProjectByIds(@RequestParam(value = "ids") List<Long> ids);

	/**
	 * 根据条件查询对应项目ID列表
	 *
	 * @param projectRange 1-全部项目，2-在建项目，3-完工项目，4-本年新签项目
	 * @return
	 */
	@GetMapping(value = "/api/project/getProjectIdsByProperties")
	CommonResponse<List<Long>> getProjectIdsByProperties(@RequestParam(value = "projectRange") int projectRange);

	/**
	 * 供方协同---用户获取有权限的项目，为空代表全部项目的权限
	 *
	 * @return
	 */
	@GetMapping(value = "/api/project/queryProjectByUserId")
	CommonResponse<List<ProjectRegisterVO>> queryProjectByUserId(@RequestParam(value = "userId") Long userId);

	/***
	 * @Author mrsir_wxp
	 * @Date 2021/2/1 查询本下启用的项目，参数为需要查询的条数，默认十条
	 * @Description queryProjectList
	 * @Param [num]
	 * @Return com.ejianc.framework.core.response.CommonResponse<java.util.List<com.ejianc.business.market.vo.ProjectRegisterVO>>
	 */
	@GetMapping(value = "/api/project/queryProjectList")
	CommonResponse<List<ProjectRegisterVO>> queryProjectList(@RequestParam(value = "num",defaultValue = "10") int num);
	/**
	 * @Author mrsir_wxp
	 * @Date 2021/5/18
	 * @Description queryProjectPage
	 * @Param [queryParam]
	 * @Return com.ejianc.framework.core.response.CommonResponse<com.baomidou.mybatisplus.core.metadata.IPage<com.ejianc.business.market.vo.ProjectRegisterVO>>
	 */
	@PostMapping(value = "/api/project/queryProjectPage")
	CommonResponse<Page<ProjectRegisterVO>> queryProjectPage(@RequestBody QueryParam queryParam);

	/**
	 * @Author zhangwx
	 * @Date 2021/06/07 根据组织主键查询本下所有项目
	 * @Description queryProjectByProjectDepartmentId
	 * @Param [orgId]
	 * @Return com.ejianc.framework.core.response.CommonResponse<java.util.List<com.ejianc.business.market.vo.ProjectRegisterVO>>
	 */
	@GetMapping(value = "/api/project/queryChildrenProjectByOrgId")
	CommonResponse<List<ProjectRegisterVO>> queryChildrenProjectByOrgId(@RequestParam(value = "orgId") Long orgId);

	/**
	 * 根据组织主键查询本下项目地址，过滤条件项目状态、关注类型
	 * @return
	 */
	@GetMapping(value = "/api/project/queryProjects")
	CommonResponse<List<Map>> queryProjects(@RequestParam(value = "orgId") Long orgId,
											@RequestParam(value = "statusList", required = false) List<String> statusList,
											@RequestParam(value = "focusTypeList", required = false) List<String> focusTypeList,
											@RequestParam(value = "engineeringTypeList", required = false) List<Long> engineeringTypeList,
											@RequestParam(value = "searchText", required = false) String searchText);
}

==> ejc-market-api-3.0.1-20221024.032623-30-sources.jar: com/ejianc/business/market/api/IProjectApi.java <==
package com.ejianc.business.market.api;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.business.market.hystrix.ProjectHystrix;
import com.ejianc.business.market.vo.ProjectRegisterVO;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.core.response.QueryParam;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;

import java.util.List;
import java.util.Map;

/**
 * 项目rpc服务
 *
 * @author cJ
 *
 */
@FeignClient(name= "ejc-market-web", url="${common.env.feign-client-url}", path="ejc-market-web", fallback = ProjectHystrix.class)
public interface IProjectApi {

	/**
	 * 根据sourceId查询项目详情
	 *
	 * @param sourceId
	 * @return
	 */
	@GetMapping(value = "/api/project/queryProjectBySourceId")
	public CommonResponse<ProjectRegisterVO> queryProjectBySourceId(@RequestParam(value = "sourceId") String sourceId);

	/**
	 * @Author mrsir_wxp
	 * @Date 2020/8/21 根据项目部id查询项目信息
	 * @Description queryProjectByProjectDepartmentId
	 * @Param [sourceId]
	 * @Return com.ejianc.framework.core.response.CommonResponse<com.ejianc.business.market.vo.ProjectRegisterVO>
	 */
	@GetMapping(value = "/api/project/queryProjectByProjectDepartmentId")
	CommonResponse<ProjectRegisterVO> queryProjectByProjectDepartmentId(@RequestParam(value = "projectDepartmentId") String projectDepartmentId);

	/**
	 * 根据ids查询项目详情
	 *
	 * @param ids
	 * @return
	 */
	@GetMapping(value = "/api/project/queryProjectByIds")
	public CommonResponse<List<ProjectRegisterVO>> queryProjectByIds(@RequestParam(value = "ids") List<Long> ids);

	/**
	 * 根据条件查询对应项目ID列表
	 *
	 * @param projectRange 1-全部项目，2-在建项目，3-完工项目，4-本年新签项目
	 * @return
	 */
	@GetMapping(value = "/api/project/getProjectIdsByProperties")
	CommonResponse<List<Long>> getProjectIdsByProperties(@RequestParam(value = "projectRange") int projectRange);

	/**
	 * 供方协同---用户获取有权限的项目，为空代表全部项目的权限
	 *
	 * @return
	 */
	@GetMapping(value = "/api/project/queryProjectByUserId")
	CommonResponse<List<ProjectRegisterVO>> queryProjectByUserId(@RequestParam(value = "userId") Long userId);

	/***
	 * @Author mrsir_wxp
	 * @Date 2021/2/1 查询本下启用的项目，参数为需要查询的条数，默认十条
	 * @Description queryProjectList
	 * @Param [num]
	 * @Return com.ejianc.framework.core.response.CommonResponse<java.util.List<com.ejianc.business.market.vo.ProjectRegisterVO>>
	 */
	@GetMapping(value = "/api/project/queryProjectList")
	CommonResponse<List<ProjectRegisterVO>> queryProjectList(@RequestParam(value = "num",defaultValue = "10") int num);
	/**
	 * @Author mrsir_wxp
	 * @Date 2021/5/18
	 * @Description queryProjectPage
	 * @Param [queryParam]
	 * @Return com.ejianc.framework.core.response.CommonResponse<com.baomidou.mybatisplus.core.metadata.IPage<com.ejianc.business.market.vo.ProjectRegisterVO>>
	 */
	@PostMapping(value = "/api/project/queryProjectPage")
	CommonResponse<Page<ProjectRegisterVO>> queryProjectPage(@RequestBody QueryParam queryParam);

	/**
	 * @Author zhangwx
	 * @Date 2021/06/07 根据组织主键查询本下所有项目
	 * @Description queryProjectByProjectDepartmentId
	 * @Param [orgId]
	 * @Return com.ejianc.framework.core.response.CommonResponse<java.util.List<com.ejianc.business.market.vo.ProjectRegisterVO>>
	 */
	@GetMapping(value = "/api/project/queryChildrenProjectByOrgId")
	CommonResponse<List<ProjectRegisterVO>> queryChildrenProjectByOrgId(@RequestParam(value = "orgId") Long orgId);

	/**
	 * 根据组织主键查询本下项目地址，过滤条件项目状态、关注类型
	 * @return
	 */
	@GetMapping(value = "/api/project/queryProjects")
	CommonResponse<List<Map>> queryProjects(@RequestParam(value = "orgId") Long orgId,
											@RequestParam(value = "statusList", required = false) List<String> statusList,
											@RequestParam(value = "focusTypeList", required = false) List<String> focusTypeList,
											@RequestParam(value = "engineeringTypeList", required = false) List<Long> engineeringTypeList,
											@RequestParam(value = "searchText", required = false) String searchText);

	/**
	 * @Author zhangwx
	 * @Date 2022/10/18 根据区域查询所有项目
	 * @Description queryListByArea
	 * @Param [orgId]
	 * @Return com.ejianc.framework.core.response.CommonResponse<java.util.List<com.ejianc.business.market.vo.ProjectRegisterVO>>
	 */
	@GetMapping(value = "/api/project/queryListByArea")
	CommonResponse<List<ProjectRegisterVO>> queryListByArea(@RequestParam(value = "areaName") String areaName);
}
